==> vala-0.1.0.tar.gz: vala-0.1.0/vala/valalockable.c <==
/* valalockable.vala
 *
 * Copyright (C) 2006  Raffaele Sandrini
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Raffaele Sandrini <rasa@gmx.ch>
 */
#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))

#include "valalockable.h"



gboolean vala_lockable_get_lock_used (ValaLockable* self)
{
	return VALA_LOCKABLE_GET_INTERFACE (self)->get_lock_used (self);
}


void vala_lockable_set_lock_used (ValaLockable* self, gboolean used)
{
	VALA_LOCKABLE_GET_INTERFACE (self)->set_lock_used (self, used);
}


static void vala_lockable_base_init (ValaLockableIface * iface)
{
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType vala_lockable_get_type ()
{
	static GType vala_lockable_type_id = 0;
	if (G_UNLIKELY (vala_lockable_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaLockableIface), (GBaseInitFunc) vala_lockable_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
		vala_lockable_type_id = g_type_register_static (G_TYPE_INTERFACE, "ValaLockable", &g_define_type_info, 0);
	}
	return vala_lockable_type_id;
}

==> vala_0.1.2.orig.tar.gz: vala-0.1.2/vala/valalockable.c <==
/* valalockable.vala
 *
 * Copyright (C) 2006  Raffaele Sandrini
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Raffaele Sandrini <rasa@gmx.ch>
 */

#include "valalockable.h"



gboolean vala_lockable_get_lock_used (ValaLockable* self)
{
	return VALA_LOCKABLE_GET_INTERFACE (self)->get_lock_used (self);
}


void vala_lockable_set_lock_used (ValaLockable* self, gboolean used)
{
	VALA_LOCKABLE_GET_INTERFACE (self)->set_lock_used (self, used);
}


static void vala_lockable_base_init (ValaLockableIface * iface)
{
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
	}
}


GType vala_lockable_get_type (void)
{
	static GType vala_lockable_type_id = 0;
	if (G_UNLIKELY (vala_lockable_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaLockableIface), (GBaseInitFunc) vala_lockable_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
		vala_lockable_type_id = g_type_register_static (G_TYPE_INTERFACE, "ValaLockable", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (vala_lockable_type_id, G_TYPE_OBJECT);
	}
	return vala_lockable_type_id;
}
